@@ -36,14 +36,8 @@ class msg_recv_Exception(Exception):
         super().__init__(message)
 
 
-
 def msg_recv(socket):
-    try:
-        N = socket.recv(1)
-    except ConnectionResetError as e:
-        raise e
-    if N == b"":
-        raise msg_recv_Exception("Socket closed")
+    N = recvNBytes(socket, 1)
     N = struct.unpack('<B', N)[0]
 
     if N != 0:
@@ -79,25 +73,33 @@ def msg_send(socket, data):
 
     for t in types:
         if N<=types[t]:
-            socket.send(struct.pack('<B', types[t]))
-            socket.send(struct.pack(t, C))
-            socket.send(data)
-            return None
+            socket.sendall(struct.pack('<B', types[t]))
+            socket.sendall(struct.pack(t, C))
+            socket.sendall(data)
+            return
 
     raise msg_send_Exception("Error in msg_send")
     
 
 def recvNBytes(socket, N):
     data = socket.recv(N)
+    checkRecvData(data)
     while getsizeof(data)-BYTES_OBJECT_OVERHEAD!=N:
-        data += socket.recv(N-getsizeof(data)+BYTES_OBJECT_OVERHEAD)
+        newData = socket.recv(N-getsizeof(data)+BYTES_OBJECT_OVERHEAD)
+        checkRecvData(data)
+        data += newData
     return data
 
 
+def checkRecvData(data):
+    if data == b"":
+        raise msg_recv_Exception("Socket closed")
+
+
+
 def msg_encode(data, key):
     pass
 
-
 def msg_decode(data, key):
     pass
 
