@@ -4,7 +4,7 @@ STATUS = {
     400:"Bad request",
     451:"Message must be a dictionary",
     452:"Missing 'action' Field",
-    453:"Missing 'name' Field",
+    453:"Name not allowed",
     454:"'name' Already Subscribed",
     455:"Missing 'to' Field",
     456:"Client Not Subscribed",
